Temperature (``taurex.temperature``)
====================================

Base
------------------------------------------------

.. automodule:: taurex.data.profiles.temperature.tprofile
   :members:
   :undoc-members:
   :show-inheritance:


Isothermal
--------------------------------------------------

.. automodule:: taurex.data.profiles.temperature.isothermal
   :members:
   :undoc-members:
   :show-inheritance:

Two-stream approximation (Guillot)
-----------------------------------------------

.. automodule:: taurex.data.profiles.temperature.guillot
   :members:
   :undoc-members:
   :show-inheritance:

Multi Point
----------------------------------------------

.. automodule:: taurex.data.profiles.temperature.npoint
   :members:
   :undoc-members:
   :show-inheritance:

Rodgers
-----------------------------------------------

.. automodule:: taurex.data.profiles.temperature.rodgers
   :members:
   :undoc-members:
   :show-inheritance:

Array
-----------------------------------------------

.. automodule:: taurex.data.profiles.temperature.temparray
   :members:
   :undoc-members:
   :show-inheritance:

File
-----------------------------------------------

.. automodule:: taurex.data.profiles.temperature.file
   :members:
   :undoc-members:
   :show-inheritance:
